"use client";

import { DocsContentMetadata } from "@/app/common/documentation";
import React, { ReactElement } from "react";
import { DialogClose } from "../ui/dialog";
import { useRouter } from "next/navigation";

type PagesProps = {
  /**
   * The documentation pages to display.
   */
  pages: DocsContentMetadata[] | undefined;
};

export function DocumentationPages({ pages }: PagesProps): ReactElement {
  const router = useRouter();

  return (
    <>
      {pages && pages.length === 0 && <p>No results found</p>}

      {pages &&
        pages.length > 1 &&
        pages.map(page => {
          return (
            <DialogClose
              key={page.slug}
              className="text-left bg-card p-2 rounded-lg"
              onClick={() => {
                router.replace(`/docs/${page.slug}`);
              }}
            >
              <h2 className="font-semibold">{page.title}</h2>
              <p className="text-accent">{page.summary}</p>
            </DialogClose>
          );
        })}
    </>
  );
}
